changeset 1697:d06c2218fab1

6866719: Rename execvpe to avoid symbol clash with glibc 2.10 Reviewed-by: darcy
author martin
date Wed, 29 Jul 2009 21:45:52 -0700
parents 120ec64ce0a9
children aee3a80312f5
files src/solaris/native/java/lang/UNIXProcess_md.c
diffstat 1 files changed, 8 insertions(+), 6 deletions(-) [+]
line wrap: on
line diff
--- a/src/solaris/native/java/lang/UNIXProcess_md.c	Sun Jun 14 14:23:22 2009 -0700
+++ b/src/solaris/native/java/lang/UNIXProcess_md.c	Wed Jul 29 21:45:52 2009 -0700
@@ -421,14 +421,16 @@
 }
 
 /**
  * execvpe should have been included in the Unix standards.
  * execvpe is identical to execvp, except that the child environment is
  * specified via the 3rd argument instead of being inherited from environ.
  */
 static void
-execvpe(const char *file,
-        const char *argv[],
-        const char *const envp[])
+JDK_execvpe(const char *file,
+            const char *argv[],
+            const char *const envp[])
 {
     /* This is one of the rare times it's more portable to declare an
      * external symbol explicitly, rather than via a system header.
@@ -617,7 +619,7 @@
     if (fcntl(FAIL_FILENO, F_SETFD, FD_CLOEXEC) == -1)
         goto WhyCantJohnnyExec;
 
-    execvpe(p->argv[0], p->argv, p->envv);
+    JDK_execvpe(p->argv[0], p->argv, p->envv);
 
  WhyCantJohnnyExec:
     /* We used to go to an awful lot of trouble to predict whether the
@@ -421,14 +421,16 @@
 
 /**
- * execvpe should have been included in the Unix standards.
- * execvpe is identical to execvp, except that the child environment is
+ * 'execvpe' should have been included in the Unix standards,
+ * and is a GNU extension in glibc 2.10.
+ *
+ * JDK_execvpe is identical to execvp, except that the child environment is
  * specified via the 3rd argument instead of being inherited from environ.
  */